@@ -89,7 +89,20 @@ def match(segment_name: str, conditions: Dict = None) -> Callable:
 
 class X12ParserContext:
     """
-    The X12ParserContext maintains the current loop position within the larger x12 transactional data structure.
+    The X12ParserContext maintains the current parsing position and provides a record cache.
+
+    The parsing position is set using `set_loop_context`, which sets the current loop name and the data structure,
+    usually a dictionary, for the loop.
+
+    Cached records include:
+    * The current subscriber record
+    * The current patient record
+    * The current hierarchical segment
+
+    The current hierarchical segment is set in the core parser. Subscriber and patient records are set manually within a
+    transaction's loop parser.
+
+    Cached record usage varies based on transaction type.
     """
 
     @property
@@ -120,6 +133,9 @@ class X12ParserContext:
         self.transaction_data["header"] = {}
         self.transaction_data["footer"] = {}
         self.is_transaction_complete = False
+        self.subscriber_record = None
+        self.patient_record = None
+        self.hl_segment = None
 
     def mark_transaction_complete(self) -> None:
         """Marks the current transaction as complete"""
@@ -137,6 +153,9 @@ class X12ParserContext:
         self.loop_container: Optional[Dict] = {}
         self.transaction_data: Optional[Dict] = {"header": {}, "footer": {}}
         self.is_transaction_complete: bool = False
+        self.subscriber_record: Optional[Dict] = None
+        self.patient_record: Optional[Dict] = None
+        self.hl_segment: Optional[Dict] = None
 
 
 class X12Parser(ABC):
@@ -255,9 +274,13 @@ class X12Parser(ABC):
     ) -> Optional[X12SegmentGroup]:
         """
         Parses an X12 segment into the instance's data record attribute.
+
+        Sets the following context attributes:
+        * hl_segment
+
         Returns a X12 Transaction Model when all segments are received.
 
-        :param segment_name: The name of the X12 segment
+        :param segment_name: The name of the X12 segment (ST, HL, NM1, etc)
         :param segment_fields: List of segment field values
         :return: The X12 Transaction Model if ready, otherwise None.
         """
@@ -267,6 +290,9 @@ class X12Parser(ABC):
         # convert segment data to a dictionary "record"
         segment_data: Dict = self._parse_segment(segment_name, segment_fields)
 
+        if segment_name.lower() == "hl":
+            self._context.hl_segment = segment_data
+
         for loop_parser in self._loop_parsers[segment_name]:
             loop_parser(segment_data, self._context)
 
