@@ -26,7 +26,6 @@ from x12.segments import (
     SeSegment,
     N3Segment,
     N4Segment,
-    PrvSegment,
     TrnSegment,
     DmgSegment,
     HiSegment,
@@ -52,8 +51,10 @@ from .segments import (
     Loop2000AHlSegment,
     Loop2000AAaaSegment,
     Loop2100CNm1Segment,
+    Loop2100DNm1Segment,
     Loop2100RefSegment,
     Loop2100CInsSegment,
+    Loop2100DInsSegment,
     Loop2100DtpSegment,
     Loop2110RefSegment,
     Loop2110DtpSegment,
@@ -126,7 +127,7 @@ class Loop2100D(X12SegmentGroup):
     Loop 2100D - Dependent Name
     """
 
-    nm1_segment: Loop2100CNm1Segment
+    nm1_segment: Loop2100DNm1Segment
     ref_segment: Optional[List[Loop2100RefSegment]] = Field(min_items=0, max_items=9)
     n3_segment: Optional[N3Segment]
     n4_segment: Optional[N4Segment]
@@ -134,7 +135,7 @@ class Loop2100D(X12SegmentGroup):
     aaa_segment: Optional[List[Loop2100BAaaSegment]] = Field(min_items=0, max_items=9)
     prv_segment: Optional[PrvSegment]
     dmg_segment: Optional[DmgSegment]
-    ins_segment: Optional[Loop2100CInsSegment]
+    ins_segment: Optional[Loop2100DInsSegment]
     hi_segment: Optional[HiSegment]
     dtp_segment: Optional[List[Loop2100DtpSegment]] = Field(min_items=0, max_items=9)
     mpi_segment: Optional[MpiSegment]
@@ -261,7 +262,7 @@ class Loop2100B(X12SegmentGroup):
     ref_segment: Optional[List[Loop2100BRefSegment]]
     n3_segment: Optional[N3Segment]
     n4_segment: Optional[N4Segment]
-    aaa_segment: Optional[Loop2100BAaaSegment]
+    aaa_segment: Optional[List[Loop2100BAaaSegment]]
     prv_segment: Optional[Loop2100BPrvSegment]
 
     _validate_ref_segments = root_validator(allow_reuse=True)(
@@ -276,7 +277,7 @@ class Loop2000B(X12SegmentGroup):
 
     hl_segment: Loop2000BHlSegment
     loop_2100b: Loop2100B
-    loop_2000c: List[Loop2000C] = Field(min_items=1)
+    loop_2000c: Optional[List[Loop2000C]]
 
 
 class Loop2100A(X12SegmentGroup):
